
/* ----- Copyright 2007 CNRS (VERIMAG) -------------------------------------
--------------------------------------------------------------------------------
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--------------------------------------------------------------------------------
 * Projet Talk to NXT
 * -------------------------------------------------------------------------
 * module   : usbnxt.h 
 *
 * date     : 2007-03-07 
 * auteurs  : Pascal Raymond
 *--------------------------------------------------------------------------
 * nature   : Classe dérivée de UsbHandle, spécialement dédiée à la brique nxt.
 *--------------------------------------------------------------------------
 * Modifs   : 2008-06-06 : 
 *            Fabien Georget 
 *            ajout des fonctions setname et fdelete et quelques modifs par ci par là !
 *            Grandes modifications pour gt2n !
 *               suppression listfiles mais ajout getFirstFile, getNextFile, closeSearch File ...
 * -----------------------------------------------------------------------*/
 
#include <string>
#include <vector>

// structure for informations about the brick
struct nxt_info{
  char pmv; //2nd part protocol
  char pMv; //1er part protocol
  char fmv; //2nd part firmware
  char fMv; //1er part firmware
  char nme[15]; // brick name
  char bt[6]; // bluetooth address
  int btsignal; //signal strenght
  int freeflash; // user free flash
  int mV; // battery level
};

// structure for files in the brick
struct nxt_file{
  std::string type;
  std::string filename;
  int filesize;
  char status;
  char cmdhdl;
};

//  Message d'erreurs de la lib ...
extern char* usbnxt_error();

class UsbNxt : public UsbHandle {
	int _fails(const char* c);
	//utile : récupère un descripteur de fichier
	int _unpack_filedesc(
		const char* fmsg,
   	char* pstatus,
   	char* pcmdhdl,
		char* pfnme, int* pfsz
	);
	//utile: teste l'existence d'un fichier
	bool _file_exists(char* nme);
	int _file_delete(const char* nme);
public :
	UsbNxt();
	int init();
	bool brickIsHere();
// Informations :
	int battery_level();
	int get_info(nxt_info* info);
	int getFirstFile(nxt_file *fileDesc);
	int getNextFile(nxt_file *fileDesc,char handle);
	int closeSearchFile(char cmdhdl);
	int upload(const char* fname);
	//fpath is the whole path ! e.g. /home/useruser/nxtprogram/hello.rxe
	int download(const char* fpath);
	int setname(const char* brickname);
	int fdelete(const char* fname);
	int startprogram(char* pname);
};
